### The help printing system

sub new {
  my $class = shift;

  $self = { printer => Printer->new, };

  bless $self, $class;
}

sub printhelp {
  my $self = shift;

  $self->{printer}->printlines((
				"You have to type in the word between []",
				"[load] Load a PNG file",
				"[dither] dither color",
				"[select] select color",
				"[aiselect] select color with AI",
			       ));
}

1;
