### The scanner of words on the command line

sub new {
  my $class = shift;

  $self = { printer => Printer->new, };

  bless $self, $class;
}

sub scan {
  my $self = shift;

  my $line = readline;
  
  ### FIXME
}

1;
