### Carry is what a message contains e.g. a Component for this program/library

sub new {
  my ($class, $data) = shift;

  ### data is e.g. a string for printing
  ### or a Component for the Compiler.pm etc
  $self = { data => $data, };

  bless $self, $class;
}

sub getData {
  my $self = shift;

  return $self->{data};
}

1;
