### A simple line printer

sub new {
  my $class = shift;

  $self = {};

  bless $self, $class;
}

sub print {
  my ($self, $asciitext) = @_;
  
  print $asciitext;
}

### print one line with newline termination
sub println {
  my ($self, $asciitext) = @_;
  
  print $asciitext . "\n";
}

sub printlines {
  my ($self, @lines) = @_;

  for (my $i = 0; $i < length(@lines); $i++) {
    print @lines[$i] . "\n";
  }
}

sub printPrompt {
  my $self = shift;

  $self->print("> ");
}
  
1;
