### Compiler of GFX-Tools commands in a shell

sub new {
  my $class = shift;

  $self = {}; ###wordlexer => WordLexer->new, };

  bless $self, $class;
}

sub addComponent {
  my ($self, $componentagg) = @_;

  $componentaddingagg->dispatch($self);
}

1;
