### A Message solely to be printed

use parent 'ParserAIMessage';

sub new {
  my ($class, $contentstring) = @_;

  $self = SUPER::ParserAIMessage->new("print", "print", $contentstring);

  bless $self, $class;
}

1;
