### This is an aggregatee for adding components to the start of the runtime

sub new {
  my $class = shift;

  $self = {};

  bless $self, $class;
}

sub dispatch {
  my ($self, $compiler) = @_;

  ### FIXME
}

1;
